@@ -24,7 +24,6 @@
 
 #include "config.h"
 #include "gchemtable-app.h"
-#include <libgnomevfs/gnome-vfs-init.h>
 #include <goffice/goffice.h>
 #include <goffice/app/go-plugin.h>
 #include <goffice/app/go-plugin-loader-module.h>
@@ -36,13 +35,14 @@ int main (int argc, char *argv[])
 {
 	textdomain (GETTEXT_PACKAGE);
 	gtk_init (&argc, &argv);
-	gnome_vfs_init ();
-	/* Initialize libgoffice */
-	libgoffice_init ();
-	/* Initialize plugins manager */
-	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_PLUGIN_LOADER_MODULE_TYPE);
 
-	new GChemTableApp ();
+	GChemTableApp *app = new GChemTableApp ();
+	/* Initialize plugins manager */
+	GSList *l = NULL;
+	l = g_slist_append (l, (void *) "GOffice_plot_xy");
+	l = g_slist_append (l, (void *) "GOffice_reg_linear");
+	go_plugins_init (NULL, NULL, l, NULL, FALSE, GO_PLUGIN_LOADER_MODULE_TYPE);
+	g_slist_free (l);
 
 	gtk_main();
 	return 0;
